@@ -1,10 +1,7 @@
 from typing import Optional
-from sys import exit, stderr
 from pathlib import Path
-from os import environ
 
-from .base import dumb_pipe, using_path, is_pipeline, \
-  RC_ENV_VAR, RC_OK
+from .base import dumb_pipe, using_path, is_pipeline
 
 from play_sounds import play_after, DEFAULT_SOUND
 import click
@@ -13,7 +10,7 @@ import click
 ENV_VAR = 'DING'
 
 
-def run(file: Path):
+def run(file: Optional[Path]):
   with play_after(file):
     if not is_pipeline():
       return
