@@ -1,39 +1,41 @@
-from contextlib import contextmanager, redirect_stdout
+from contextlib import contextmanager
 from typing import Optional, ContextManager
-from sys import stdin, stdout, exit, stderr
+from sys import stdin, stdout, stderr, exit
 from pathlib import Path
 from os import environ
-import sys
-import subprocess
+#from subprocess import run
 
 from play_sounds import DEFAULT_SONG
-from detect import unix as IS_UNIX
-import click
 
 
 RC_OK = 0
 RC_ENV_VAR = 1
 ENV_VAR = 'ONHOLD'
-BLOCK_WHILE_PLAYING = True
+
+KB = 2 ** 10
+CHUNK = 64 * KB
 
 
 def is_pipeline() -> bool:
   return not stdin.isatty()
 
 
+# python 3.8+ compatible
+#def dumb_pipe():
+#  while data := stdin.buffer.read(CHUNK):
+#    stdout.buffer.write(data)
+
+
+# python 3.6 compatible
 def dumb_pipe():
-  if IS_UNIX:
-    # if we're on unix, just redirect via shell
-    subprocess.run(
-      "cat",
-      shell=True,
-      stdin=stdin,
-      stdout=stdout
-    )
+  while True:
+    data = stdin.buffer.read(CHUNK)
+
+    if not data:
+      break
+
+    stdout.buffer.write(data)
 
-  else:
-    # if we're on windows, iterate over stdin
-    stdout.buffer.writelines(stdin.buffer)
 
 
 @contextmanager
